@@ -1,9 +1,11 @@
 mod arc;
 mod quarter_circle;
 mod rectangle;
+mod textbox;
 mod thick_arc;
 
 pub use arc::*;
 pub use quarter_circle::*;
 pub use rectangle::*;
+pub use textbox::*;
 pub use thick_arc::*;
